@@ -195,6 +195,8 @@ class Trace(AbstractTrace):
         # default to an empty set, 'type' in trace.types should be possible
         # note that a modeled trace class below would override this
         self.types = self.get('types', set())
+        # invocations of the update method are counted, see Trace.update method
+        self._update_count = 0
 
         self._tags = None
         self._notes = None
@@ -522,6 +524,13 @@ class Trace(AbstractTrace):
             ``trace.context.trace(trace.uid)`` to request a new instance of
             a trace with this `.Trace`'s identifier.
 
+            Please note that, for performance reasons, all changes are buffered and not directly effective in
+            subsequent search, update and import requests. As a consequence, successive changes to a single
+            trace might be ignored. Instead, all changes to an individual trace should be bundled in a single
+            update or import request.
+            The project index is refreshed automatically (by default every 30 seconds), so changes will become
+            visible eventually.
+
         :param key_or_updates: either a `str` (the metadata property to be
             updated) or a mapping supplying both keys and values to be updated
             (or `None` if only data is supplied)
@@ -533,6 +542,13 @@ class Trace(AbstractTrace):
             overwritten if already present
         :return: processing information from remote
         """
+        # count invocations of the update method
+        self._update_count += 1
+
+        if self._update_count > 1:
+            log.warn("This trace ({}) is being updated more than once. This could result in lost updates, please "
+                     "supply a mapping with all batched updates instead of single keys and values.", self.id)
+
         updates = key_or_updates
         if isinstance(key_or_updates, str):
             updates = {key_or_updates: value}
